@@ -16,6 +16,7 @@ import pt from "./pt.json";
 import ptBR from "./pt-br.json";
 import ro from "./ro.json";
 import ru from "./ru.json";
+import sk from "./sk.json";
 import svSE from "./sv-se.json";
 import zhCN from "./zh-cn.json";
 import zhTW from "./zh-tw.json";
@@ -70,6 +71,9 @@ export function detectLocale() {
     case /^ko.*/i.test(locale):
       locale = "ko";
       break;
+    case /^sk.*/i.test(locale):
+      locale = "sk";
+      break;
     default:
       locale = "en";
   }
@@ -107,6 +111,7 @@ const i18n = new VueI18n({
     pt: removeEmpty(pt),
     ru: removeEmpty(ru),
     ro: removeEmpty(ro),
+    sk: removeEmpty(sk),
     "sv-se": removeEmpty(svSE),
     "zh-cn": removeEmpty(zhCN),
     "zh-tw": removeEmpty(zhTW),
